Tabulate function to display variables in a given domain
Source:R/table_variables.R
table_variables.RdUses table() to display the variables contained within an SDTM formatted data frame. Additionally can be split by STUDYID to display the options across multiple studies.
Arguments
- data
Domain data frame.
- domain
Character. The two letter code for the domain which matches the data. Domains included: "DM", "LB", "RP", "MB", "MP", "SA", "IN", "VS", "DS", "RS", "PO", "SC", "HO", "ER", "DD", "PF", "AU", "PC", "PE".
- by_STUDYID
Boolean. Split data by STUDYID if TRUE. Default is FALSE.